@@ -1,7 +1,7 @@
 package BioX::Workflow;
 
 use 5.008_005;
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 
 use Moose;
 use File::Find::Rule;
@@ -201,6 +201,37 @@ has 'min' => (
     default => 0,
 );
 
+=head3 number_rules
+
+    Instead of
+    outdir/
+        rule1
+        rule2
+
+    outdir/
+        001-rule1
+        002-rule2
+
+=cut
+
+has 'number_rules' => (
+    is => 'rw',
+    isa => 'Bool',
+    default => 0,
+);
+
+has 'counter_rules' => (
+    traits  => ['Counter'],
+    is => 'rw',
+    isa => 'Num',
+    default => 1,
+    handles => {
+        inc_counter_rules   => 'inc',
+        dec_counter_rules   => 'dec',
+        reset_counter_rules => 'reset',
+    },
+);
+
 =head3 auto_name
 
 Auto_name - Create outdirectory based on rulename
@@ -1050,6 +1081,15 @@ sub process_rules {
 
     foreach my $p ( @{$process} ) {
         next unless $p;
+        if($self->number_rules){
+            my @keys = keys %{$p};
+            my $result = sprintf("%04d", $self->counter_rules);
+            my $newkey = $keys[0];
+            $newkey = $result.'-'.$newkey;
+            $p->{$newkey} = dclone($p->{$keys[0]});
+            delete $p->{$keys[0]};
+            $self->inc_counter_rules;
+        }
         $self->local_rule($p);
         $self->dothings;
     }
